<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Shape</name>
    <message>
        <location filename="../Shape.js" line="+75"/>
        <source>Shape Tools</source>
        <translation>Vormgereedschappen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show shape tools</source>
        <translation>Vormgereedschappen tonen</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Shape</source>
        <translation>&amp;Vorm</translation>
    </message>
    <message>
        <location filename="../Shape.ui" line="+17"/>
        <source>Create polyline</source>
        <translation>Polylijn tekenen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fill</source>
        <translation>Vulling</translation>
    </message>
</context>
</TS>
